gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[gnunet-scheme] 28/49: dht/client: Copy the key into the put message.


From: gnunet
Subject: [gnunet-scheme] 28/49: dht/client: Copy the key into the put message.
Date: Sat, 25 Dec 2021 23:00:05 +0100

This is an automated email from the git hooks/post-receive script.

maxime-devos pushed a commit to branch master
in repository gnunet-scheme.

commit 716a580d04eb717b3fd4a73e67fad69f42051536
Author: Maxime Devos <maximedevos@telenet.be>
AuthorDate: Thu Sep 30 21:05:21 2021 +0200

    dht/client: Copy the key into the put message.
    
    * gnu/gnunet/dht/client.scm (put!): Set the 'key' field of the put
      message appropriately.
---
 gnu/gnunet/dht/client.scm | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/gnu/gnunet/dht/client.scm b/gnu/gnunet/dht/client.scm
index 4ee6655..f70dd2b 100644
--- a/gnu/gnunet/dht/client.scm
+++ b/gnu/gnunet/dht/client.scm
@@ -218,7 +218,8 @@ TODO expiration, replication, confirm ..."
       (set%! /:msg:dht:client:put '(desired-replication-level) meta
             desired-replication-level)
       (set%! /:msg:dht:client:put '(expiration) meta 0) ; TODO
-      ;; Copy data to insert into the DHT.
+      ;; Copy key-data pair to insert into the DHT.
+      (slice-copy! key (select /:msg:dht:client:put '(key) meta))
       (slice-copy! data
                   (slice-slice put-message (sizeof /:msg:dht:client:put '())))
       (define handle (%make-put server confirmed put-message))

-- 
To stop receiving notification emails like this one, please contact
gnunet@gnunet.org.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]